pub struct InboundOutcome {
pub outbound: Vec<FixMessage>,
pub application: Option<FixMessage>,
pub gap_detected: Option<(u64, u64)>,
pub ignored_duplicate: bool,
}Expand description
The result of FixSession::handle_inbound.
Fields
outbound: Vec<FixMessage>Administrative replies the session wants to send, in order.
application: Option<FixMessage>An application message to surface to the application, if any.
gap_detected: Option<(u64, u64)>Some((expected, received)) when a sequence gap was detected.
ignored_duplicate: boolTrue when a stale duplicate / malformed message was ignored.